@@ -71,7 +71,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 26547152 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 26720838 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -358,7 +358,7 @@ fi
 journalctl=`which journalctl 2> /dev/null | head -n 1`
 
 if [ $? -eq 0 -a -x "$journalctl" ]; then
-    for comm in Xorg Xorg.bin X; do
+    for comm in Xorg Xorg.bin X gdm-x-session; do
         for boot in -0 -1 -2; do
             if journalctl -b $boot -n 1 _COMM=$comm >/dev/null 2>&1; then
                 (
